summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-25 00:14:14 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-25 00:14:14 -0600
commitae3203e4a4717c90e6364c5a66a0d9a5dd5b7c4d (patch)
tree20f26768274e8db3212123cf1991ec916f01d0cb
parent46164d2bf7219e6db2daf81d76cf45301d97c10f (diff)
downloadtde-systemsettings-ae3203e4a4717c90e6364c5a66a0d9a5dd5b7c4d.tar.gz
tde-systemsettings-ae3203e4a4717c90e6364c5a66a0d9a5dd5b7c4d.zip
Rename KCModule, KConfig, KIO, KServer, and KSocket to avoid conflicts with KDE4
-rw-r--r--systemsettings/kcmodulemenu.cpp28
-rw-r--r--systemsettings/kcmodulemenu.h14
-rw-r--r--systemsettings/kcmsearch.cpp4
-rw-r--r--systemsettings/kcmsearch.h2
-rw-r--r--systemsettings/kcmultiwidget.cpp38
-rw-r--r--systemsettings/kcmultiwidget.h24
-rw-r--r--systemsettings/mainwindow.cpp12
-rw-r--r--systemsettings/mainwindow.h8
-rw-r--r--systemsettings/moduleiconitem.cpp2
-rw-r--r--systemsettings/moduleiconitem.h4
-rw-r--r--systemsettings/modulesview.cpp2
-rw-r--r--systemsettings/modulesview.h6
12 files changed, 72 insertions, 72 deletions
diff --git a/systemsettings/kcmodulemenu.cpp b/systemsettings/kcmodulemenu.cpp
index 3d36388..24660d9 100644
--- a/systemsettings/kcmodulemenu.cpp
+++ b/systemsettings/kcmodulemenu.cpp
@@ -24,17 +24,17 @@
#include <kdebug.h>
#include <tqdict.h>
-class KCModuleMenuPrivate {
+class TDECModuleMenuPrivate {
public:
- KCModuleMenuPrivate(){
+ TDECModuleMenuPrivate(){
}
TQMap<TQString, TQValueList<MenuItem> > menus;
TQString basePath;
};
-KCModuleMenu::KCModuleMenu( const TQString &menuName ) :
- d( new KCModuleMenuPrivate )
+TDECModuleMenu::TDECModuleMenu( const TQString &menuName ) :
+ d( new TDECModuleMenuPrivate )
{
kdDebug() << "MenuName: \"" << menuName << "\"." << endl;
// Make sure we can find the menu
@@ -48,12 +48,12 @@ KCModuleMenu::KCModuleMenu( const TQString &menuName ) :
readMenu( d->basePath );
}
-KCModuleMenu::~KCModuleMenu()
+TDECModuleMenu::~TDECModuleMenu()
{
delete d;
}
-void KCModuleMenu::readMenu( const TQString &pathName )
+void TDECModuleMenu::readMenu( const TQString &pathName )
{
KServiceGroup::Ptr group = KServiceGroup::group( pathName );
if ( !group || !group->isValid() )
@@ -71,7 +71,7 @@ void KCModuleMenu::readMenu( const TQString &pathName )
{
KSycocaEntry *entry = (*it);
if( addEntry(entry) ) {
- KCModuleInfo module((KService*)entry);
+ TDECModuleInfo module((KService*)entry);
append(module);
MenuItem infoItem(false);
infoItem.caption = this->deriveCaptionFromPath(entry->name());
@@ -92,7 +92,7 @@ void KCModuleMenu::readMenu( const TQString &pathName )
d->menus.insert( pathName, currentMenu );
}
-bool KCModuleMenu::addEntry( KSycocaEntry *entry ){
+bool TDECModuleMenu::addEntry( KSycocaEntry *entry ){
if( !entry->isType(KST_KService) )
return false;
@@ -100,7 +100,7 @@ bool KCModuleMenu::addEntry( KSycocaEntry *entry ){
if ( !kapp->authorizeControlModule( service->menuId()) )
return false;
- KCModuleInfo module( service );
+ TDECModuleInfo module( service );
if ( module.library().isEmpty() )
return false;
@@ -108,9 +108,9 @@ bool KCModuleMenu::addEntry( KSycocaEntry *entry ){
}
-TQValueList<KCModuleInfo> KCModuleMenu::modules( const TQString &menuPath )
+TQValueList<TDECModuleInfo> TDECModuleMenu::modules( const TQString &menuPath )
{
- TQValueList<KCModuleInfo> list;
+ TQValueList<TDECModuleInfo> list;
TQValueList<MenuItem> subMenu = menuList(menuPath);
TQValueList<MenuItem>::iterator it;
@@ -122,7 +122,7 @@ TQValueList<KCModuleInfo> KCModuleMenu::modules( const TQString &menuPath )
return list;
}
-TQStringList KCModuleMenu::submenus( const TQString &menuPath )
+TQStringList TDECModuleMenu::submenus( const TQString &menuPath )
{
TQStringList list;
@@ -136,7 +136,7 @@ TQStringList KCModuleMenu::submenus( const TQString &menuPath )
return list;
}
-TQValueList<MenuItem> KCModuleMenu::menuList( const TQString &menuPath )
+TQValueList<MenuItem> TDECModuleMenu::menuList( const TQString &menuPath )
{
if( menuPath.isEmpty() ) {
if( d->basePath.isEmpty())
@@ -171,7 +171,7 @@ TQValueList<MenuItem> KCModuleMenu::menuList( const TQString &menuPath )
*
* "Michael D. Stemle, Jr." <manchicken@notsosoft.net>
*/
-TQString KCModuleMenu::deriveCaptionFromPath( const TQString &menuPath )
+TQString TDECModuleMenu::deriveCaptionFromPath( const TQString &menuPath )
{
TQStringList parts(TQStringList::split("/",menuPath));
TQString result("");
diff --git a/systemsettings/kcmodulemenu.h b/systemsettings/kcmodulemenu.h
index d6b61c0..7350b19 100644
--- a/systemsettings/kcmodulemenu.h
+++ b/systemsettings/kcmodulemenu.h
@@ -22,7 +22,7 @@
#include <kcmoduleinfo.h>
-class KCModuleMenuPrivate;
+class TDECModuleMenuPrivate;
/**
* List of all KCM modules inside a FreeDesktop.org menu
@@ -79,11 +79,11 @@ public:
bool menu;
TQString subMenu;
TQString caption;
- KCModuleInfo item;
+ TDECModuleInfo item;
};
-class KCModuleMenu : public TQValueList<KCModuleInfo>
+class TDECModuleMenu : public TQValueList<TDECModuleInfo>
{
public:
@@ -98,12 +98,12 @@ public:
* X-TDE-BaseGroup=examplemenu
* so menuName should be "systemsettings"
*/
- KCModuleMenu( const TQString &menuName );
+ TDECModuleMenu( const TQString &menuName );
/**
* Deconstructor
*/
- virtual ~KCModuleMenu();
+ virtual ~TDECModuleMenu();
/**
* Returns item of a menu path. An empty string is the top level.
@@ -118,7 +118,7 @@ public:
* @param menu to return modules from.
* @returns only the top level modules of menuPath
*/
- TQValueList<KCModuleInfo> modules( const TQString &menuPath=TQString() );
+ TQValueList<TDECModuleInfo> modules( const TQString &menuPath=TQString() );
/**
* Returns the sub menus of a menu path. An empty string is the top level.
@@ -150,7 +150,7 @@ protected:
virtual bool addEntry( KSycocaEntry *entry );
private:
- KCModuleMenuPrivate *d;
+ TDECModuleMenuPrivate *d;
TQString deriveCaptionFromPath( const TQString &menuPath );
};
diff --git a/systemsettings/kcmsearch.cpp b/systemsettings/kcmsearch.cpp
index 8cfb319..ac97647 100644
--- a/systemsettings/kcmsearch.cpp
+++ b/systemsettings/kcmsearch.cpp
@@ -62,7 +62,7 @@ void KcmSearch::updateSearch( const TQString &search ) {
delete[] hitArray;
}
-bool KcmSearch::itemMatches( const KCModuleInfo &module, const TQString &search ) const
+bool KcmSearch::itemMatches( const TDECModuleInfo &module, const TQString &search ) const
{
// Look in keywords
TQStringList kw = module.keywords();
@@ -89,7 +89,7 @@ bool KcmSearch::itemMatches( const TQIconViewItem *item, const TQString & search
return false;
ModuleIconItem *mItem = (ModuleIconItem*)item;
- TQValueList<KCModuleInfo>::iterator it;
+ TQValueList<TDECModuleInfo>::iterator it;
for ( it = mItem->modules.begin(); it != mItem->modules.end(); ++it ){
if( itemMatches( (*it), search ) )
return true;
diff --git a/systemsettings/kcmsearch.h b/systemsettings/kcmsearch.h
index 55a88de..970b52f 100644
--- a/systemsettings/kcmsearch.h
+++ b/systemsettings/kcmsearch.h
@@ -58,7 +58,7 @@ private:
* Determine if module matches the search
* @return true if search is in module's keywords
*/
- bool itemMatches ( const KCModuleInfo &module, const TQString &search ) const;
+ bool itemMatches ( const TDECModuleInfo &module, const TQString &search ) const;
// Friend class whos groups parsed,
TQPtrList<ModulesView> *moduleViewList;
diff --git a/systemsettings/mainwindow.cpp b/systemsettings/mainwindow.cpp
index 3cd07d8..941abde 100644
--- a/systemsettings/mainwindow.cpp
+++ b/systemsettings/mainwindow.cpp
@@ -57,7 +57,7 @@ MainWindow::MainWindow(bool embed, const TQString & menuFile,
groupWidget(NULL), selectedPage(0), dummyAbout(NULL) {
// Load the menu structure in from disk.
- menu = new KCModuleMenu( menuFile );
+ menu = new TDECModuleMenu( menuFile );
moduleTabs = new KTabWidget(this, "moduletabs",
TQTabWidget::Top|TQTabWidget::Rounded);
@@ -190,7 +190,7 @@ void MainWindow::aboutCurrentModule()
if(!groupWidget)
return;
- KCModuleProxy* module = groupWidget->currentModule();
+ TDECModuleProxy* module = groupWidget->currentModule();
if( module && module->aboutData() ){
KAboutApplication dlg( module->aboutData() );
dlg.exec();
@@ -237,7 +237,7 @@ void MainWindow::slotItemSelected( TQIconViewItem *item ){
scrollView = moduleItemToScrollerDict.find(mItem);
if(groupWidget==0) {
- TQValueList<KCModuleInfo> list = mItem->modules;
+ TQValueList<TDECModuleInfo> list = mItem->modules;
KDialogBase::DialogType type = KDialogBase::IconList;
if(list.count() == 1) {
type=KDialogBase::Plain;
@@ -250,12 +250,12 @@ void MainWindow::slotItemSelected( TQIconViewItem *item ){
moduleItemToScrollerDict.insert(mItem,scrollView);
moduleItemToWidgetDict.insert(mItem,groupWidget);
- connect(groupWidget, TQT_SIGNAL(aboutToShow( KCModuleProxy * )), TQT_TQOBJECT(this), TQT_SLOT(updateModuleHelp( KCModuleProxy * )));
+ connect(groupWidget, TQT_SIGNAL(aboutToShow( TDECModuleProxy * )), TQT_TQOBJECT(this), TQT_SLOT(updateModuleHelp( TDECModuleProxy * )));
connect(groupWidget, TQT_SIGNAL(aboutToShowPage( TQWidget* )), TQT_TQOBJECT(this), TQT_SLOT(widgetChange()));
connect(groupWidget, TQT_SIGNAL(finished()), TQT_TQOBJECT(this), TQT_SLOT(groupModulesFinished()));
connect(groupWidget, TQT_SIGNAL(close()), TQT_TQOBJECT(this), TQT_SLOT(showAllModules()));
- TQValueList<KCModuleInfo>::iterator it;
+ TQValueList<TDECModuleInfo>::iterator it;
for ( it = list.begin(); it != list.end(); ++it ){
tqDebug("adding %s %s", (*it).moduleName().latin1(), (*it).fileName().latin1());
groupWidget->addModule( *it );
@@ -298,7 +298,7 @@ void MainWindow::timerResize() {
}
}
-void MainWindow::updateModuleHelp( KCModuleProxy *currentModule ) {
+void MainWindow::updateModuleHelp( TDECModuleProxy *currentModule ) {
if ( currentModule->aboutData() ) {
aboutModuleAction->setText(i18n("Help menu->about <modulename>", "About %1").arg(
currentModule->moduleInfo().moduleName().replace("&","&&")));
diff --git a/systemsettings/mainwindow.h b/systemsettings/mainwindow.h
index 37a81f8..de7d2fb 100644
--- a/systemsettings/mainwindow.h
+++ b/systemsettings/mainwindow.h
@@ -38,8 +38,8 @@ class KCMultiWidget;
class ModulesView;
class KAction;
class KWidgetAction;
-class KCModule;
-class KCModuleProxy;
+class TDECModule;
+class TDECModuleProxy;
class MainWindow : public KMainWindow
{
@@ -55,7 +55,7 @@ private slots:
void slotItemSelected( TQIconViewItem* item );
void showAllModules();
void aboutCurrentModule();
- void updateModuleHelp( KCModuleProxy * );
+ void updateModuleHelp( TDECModuleProxy * );
void resetModuleHelp();
void groupModulesFinished();
@@ -66,7 +66,7 @@ private slots:
void slotSearchHits(const TQString &query, int *hitList, int length);
private:
- KCModuleMenu *menu;
+ TDECModuleMenu *menu;
bool embeddedWindows;
TQWidgetStack *windowStack;
KTabWidget *moduleTabs;
diff --git a/systemsettings/moduleiconitem.cpp b/systemsettings/moduleiconitem.cpp
index 74fedab..21838fb 100644
--- a/systemsettings/moduleiconitem.cpp
+++ b/systemsettings/moduleiconitem.cpp
@@ -24,7 +24,7 @@
#define IMAGE_SIZE 32
-ModuleIconItem::ModuleIconItem( KIconView *parent, KCModuleInfo module)
+ModuleIconItem::ModuleIconItem( KIconView *parent, TDECModuleInfo module)
: TQIconViewItem( parent, module.moduleName(),
SmallIcon( module.icon(), IMAGE_SIZE ) ),
currentState( KIcon::ActiveState), imageName(module.icon())
diff --git a/systemsettings/moduleiconitem.h b/systemsettings/moduleiconitem.h
index f6a69a0..99d16ec 100644
--- a/systemsettings/moduleiconitem.h
+++ b/systemsettings/moduleiconitem.h
@@ -35,7 +35,7 @@ class ModuleIconItem : public TQIconViewItem
{
public:
- ModuleIconItem( KIconView *parent, KCModuleInfo module );
+ ModuleIconItem( KIconView *parent, TDECModuleInfo module );
ModuleIconItem( KIconView *parent, const TQString &text,
const TQString &imageName );
@@ -46,7 +46,7 @@ public:
void loadIcon( bool enabled = true );
// The modules that go with this item
- TQValueList<KCModuleInfo> modules;
+ TQValueList<TDECModuleInfo> modules;
private:
int currentState;
diff --git a/systemsettings/modulesview.cpp b/systemsettings/modulesview.cpp
index 83581da..13384d8 100644
--- a/systemsettings/modulesview.cpp
+++ b/systemsettings/modulesview.cpp
@@ -37,7 +37,7 @@
#include "moduleiconitem.h"
#include "kcmodulemenu.h"
-ModulesView::ModulesView( KCModuleMenu *rootMenu, const TQString &menuPath, TQWidget *parent,
+ModulesView::ModulesView( TDECModuleMenu *rootMenu, const TQString &menuPath, TQWidget *parent,
const char *name ) : TQWidget( parent, name ), rootMenu( NULL )
{
this->rootMenu = rootMenu;
diff --git a/systemsettings/modulesview.h b/systemsettings/modulesview.h
index 02fe435..c0640b6 100644
--- a/systemsettings/modulesview.h
+++ b/systemsettings/modulesview.h
@@ -65,7 +65,7 @@ public:
};
class TQBoxLayout;
-class KCModuleMenu;
+class TDECModuleMenu;
/**
* This widget contains the IconView's of all of the modules etc
@@ -86,12 +86,12 @@ signals:
void itemSelected( TQIconViewItem* item );
public:
- ModulesView( KCModuleMenu *rootMenu, const TQString &menuPath, TQWidget *parent=0, const char *name=0 );
+ ModulesView( TDECModuleMenu *rootMenu, const TQString &menuPath, TQWidget *parent=0, const char *name=0 );
~ModulesView();
private:
TQValueList<RowIconView*> groups;
- KCModuleMenu *rootMenu;
+ TDECModuleMenu *rootMenu;
TQString menuPath;
void createRow( const TQString &parentPath, TQBoxLayout *layout );
diff --git a/systemsettings/kcmultiwidget.cpp b/systemsettings/kcmultiwidget.cpp
index cfd5b5e..7c2eace 100644
--- a/systemsettings/kcmultiwidget.cpp
+++ b/systemsettings/kcmultiwidget.cpp
@@ -58,7 +58,7 @@ class KCMultiWidget::KCMultiWidgetPrivate
{}
bool hasRootKCM;
- KCModuleProxy* currentModule;
+ TDECModuleProxy* currentModule;
};
@@ -140,7 +140,7 @@ void KCMultiWidget::apply()
ModuleList::Iterator end = m_modules.end();
for( ModuleList::Iterator it = m_modules.begin(); it != end; ++it )
{
- KCModuleProxy * m = ( *it ).kcm;
+ TDECModuleProxy * m = ( *it ).kcm;
if( m && m->changed() )
{
m->save();
@@ -233,10 +233,10 @@ void KCMultiWidget::addModule(const TQString& path, bool withfallback)
KService::Ptr service = KService::serviceByStorageId( complete );
- addModule( KCModuleInfo( service ), TQStringList(), withfallback);
+ addModule( TDECModuleInfo( service ), TQStringList(), withfallback);
}
-void KCMultiWidget::addModule(const KCModuleInfo& moduleinfo,
+void KCMultiWidget::addModule(const TDECModuleInfo& moduleinfo,
TQStringList parentmodulenames, bool withfallback)
{
if( !moduleinfo.service() )
@@ -245,7 +245,7 @@ void KCMultiWidget::addModule(const KCModuleInfo& moduleinfo,
if ( !kapp->authorizeControlModule( moduleinfo.service()->menuId() ))
return;
- if( !KCModuleLoader::testModule( moduleinfo ))
+ if( !TDECModuleLoader::testModule( moduleinfo ))
return;
TQFrame* page = 0;
@@ -274,17 +274,17 @@ void KCMultiWidget::addModule(const KCModuleInfo& moduleinfo,
break;
}
if(!page) {
- KCModuleLoader::unloadModule(moduleinfo);
+ TDECModuleLoader::unloadModule(moduleinfo);
return;
}
- KCModuleProxy * module;
+ TDECModuleProxy * module;
if( m_orphanModules.contains( moduleinfo.service() ) )
{
// the KCModule already exists - it was removed from the dialog in
// removeAllModules
module = m_orphanModules[ moduleinfo.service() ];
m_orphanModules.remove( moduleinfo.service() );
- kdDebug( 710 ) << "Use KCModule from the list of orphans for " <<
+ kdDebug( 710 ) << "Use TDECModule from the list of orphans for " <<
moduleinfo.moduleName() << ": " << module << endl;
module->reparent( page, 0, TQPoint( 0, 0 ), true );
@@ -298,7 +298,7 @@ void KCMultiWidget::addModule(const KCModuleInfo& moduleinfo,
}
else
{
- module = new KCModuleProxy( moduleinfo, withfallback, page );
+ module = new TDECModuleProxy( moduleinfo, withfallback, page );
TQStringList parentComponents = moduleinfo.service()->property(
"X-TDE-ParentComponents" ).toStringList();
@@ -331,14 +331,14 @@ void KCMultiWidget::addModule(const KCModuleInfo& moduleinfo,
}
}
-KCModuleProxy * KCMultiWidget::currentModule() {
+TDECModuleProxy * KCMultiWidget::currentModule() {
if(d) {
return d->currentModule;
}
return NULL;
}
-void KCMultiWidget::applyOrRevert(KCModuleProxy * module){
+void KCMultiWidget::applyOrRevert(TDECModuleProxy * module){
if( !module || !module->changed() )
return;
@@ -359,11 +359,11 @@ void KCMultiWidget::applyOrRevert(KCModuleProxy * module){
void KCMultiWidget::slotAboutToShow(TQWidget *page)
{
- TQObject * obj = page->child( 0, "KCModuleProxy" );
+ TQObject * obj = page->child( 0, "TDECModuleProxy" );
if( ! obj )
return;
- KCModuleProxy *module = ( KCModuleProxy* )obj->tqt_cast( "KCModuleProxy" );
+ TDECModuleProxy *module = ( TDECModuleProxy* )obj->tqt_cast( "TDECModuleProxy" );
if( ! module )
return;
@@ -382,14 +382,14 @@ void KCMultiWidget::slotAboutToShow(TQWidget *page)
}
}
- showButton(Apply, buttons & KCModule::Apply);
- showButton(User1, buttons & KCModule::Apply); // Reset button.
+ showButton(Apply, buttons & TDECModule::Apply);
+ showButton(User1, buttons & TDECModule::Apply); // Reset button.
// Close button. No Apply button implies a Close button.
- showButton(User2, (buttons & KCModule::Apply)==0);
+ showButton(User2, (buttons & TDECModule::Apply)==0);
- enableButton( KDialogBase::Help, buttons & KCModule::Help );
- enableButton( KDialogBase::Default, buttons & KCModule::Default );
+ enableButton( KDialogBase::Help, buttons & TDECModule::Help );
+ enableButton( KDialogBase::Default, buttons & TDECModule::Default );
disconnect( this, TQT_SIGNAL(user3Clicked()), 0, 0 );
@@ -274,17 +274,17 @@ void KCMultiWidget::addModule(const KCModuleInfo& moduleinfo,
if( m_orphanModules.contains( moduleinfo.service() ) )
{
- // the KCModule already exists - it was removed from the dialog in
+ // the TDECModule already exists - it was removed from the dialog in
// removeAllModules
module = m_orphanModules[ moduleinfo.service() ];
diff --git a/systemsettings/kcmultiwidget.h b/systemsettings/kcmultiwidget.h
index 61a144e..a64ce72 100644
--- a/systemsettings/kcmultiwidget.h
+++ b/systemsettings/kcmultiwidget.h
@@ -29,9 +29,9 @@
#include <klocale.h>
#include <kservice.h>
-class KCModuleProxy;
-class KCModuleInfo;
-class KCModule;
+class TDECModuleProxy;
+class TDECModuleInfo;
+class TDECModule;
/**
* @short A method that offers a KDialogBase containing arbitrary
@@ -86,7 +86,7 @@ public:
/**
* Add a module.
*
* @param moduleinfo Pass a KCModuleInfo object which will be
* used for creating the module. It will be added
* to the list of modules the dialog will show.
*
@@ -98,17 +98,17 @@ public:
* @param withfallback Try harder to load the module. Might result
* in the module appearing outside the dialog.
**/
- void addModule(const KCModuleInfo& moduleinfo, TQStringList
+ void addModule(const TDECModuleInfo& moduleinfo, TQStringList
parentmodulenames = TQStringList(), bool withfallback=false);
/**
* @return the current module that is being shown.
*/
- KCModuleProxy * currentModule();
+ TDECModuleProxy * currentModule();
signals:
/**
- * Emitted after all KCModules have been told to save their configuration.
+ * Emitted after all TDECModules have been told to save their configuration.
*
* The applyClicked and okClicked signals are emitted before the
* configuration is saved.
@@ -116,7 +116,7 @@ signals:
void configCommitted();
/**
- * Emitted after the KCModules have been told to save their configuration.
+ * Emitted after the TDECModules have been told to save their configuration.
* It is emitted once for every instance the KCMs that were changed belong
* to.
*
@@ -139,7 +139,7 @@ signals:
* @param moduleinfo The module that is about to be shown.
* @sense 3.4
*/
- void aboutToShow( KCModuleProxy *moduleProxy );
+ void aboutToShow( TDECModuleProxy *moduleProxy );
void close();
@@ -226,14 +226,14 @@ private slots:
private:
- void applyOrRevert(KCModuleProxy * module);
+ void applyOrRevert(TDECModuleProxy * module);
void init();
void apply();
struct CreatedModule
{
- KCModuleProxy * kcm;
+ TDECModuleProxy * kcm;
KService::Ptr service;
bool adminmode;
int buttons;
@@ -241,7 +241,7 @@ private:
typedef TQValueList<CreatedModule> ModuleList;
ModuleList m_modules;
- typedef TQMap<KService::Ptr, KCModuleProxy*> OrphanMap;
+ typedef TQMap<KService::Ptr, TDECModuleProxy*> OrphanMap;
OrphanMap m_orphanModules;
TQPtrDict<TQStringList> moduleParentComponents;
@@ -86,7 +86,7 @@ public:
* Add a module.
*
- * @param moduleinfo Pass a KCModuleInfo object which will be
+ * @param moduleinfo Pass a TDECModuleInfo object which will be
* used for creating the module. It will be added
* to the list of modules the dialog will show.